@@ -51,8 +51,8 @@ var NAVTREEINDEX0 =
 "gamma_8h.html#a6df9d71211778ad700618ffadb83d268":[3,0,2,7,1],
 "gamma_8h.html#a74f51555b4b41aed7e6b5d575d845e11":[3,0,2,7,0],
 "gamma_8h_source.html":[3,0,2,7],
-"globals.html":[3,1,0],
 "globals.html":[3,1,0,0],
+"globals.html":[3,1,0],
 "globals_b.html":[3,1,0,1],
 "globals_c.html":[3,1,0,2],
 "globals_d.html":[3,1,0,3],
@@ -74,7 +74,7 @@ var NAVTREEINDEX0 =
 "globals_type.html":[3,1,3],
 "globals_vars.html":[3,1,2],
 "gphoto2-abilities-list_8c.html":[3,0,2,8],
-"gphoto2-abilities-list_8c.html#a0106fb969b8c3110101d4270607148ff":[3,0,2,8,11],
+"gphoto2-abilities-list_8c.html#a0106fb969b8c3110101d4270607148ff":[3,0,2,8,12],
 "gphoto2-abilities-list_8c.html#a0c449b4f3481ce5a8611b052dbd7f88d":[3,0,2,8,8],
 "gphoto2-abilities-list_8c.html#a125df89361f5565ab6b65127be3c92b1":[3,0,2,8,7],
 "gphoto2-abilities-list_8c.html#a1721e090bfed621b3d579616f7af7f7b":[3,0,2,8,9],
@@ -83,6 +83,7 @@ var NAVTREEINDEX0 =
 "gphoto2-abilities-list_8c.html#a8880b2ceed89e39933df14a5a80f8163":[3,0,2,8,4],
 "gphoto2-abilities-list_8c.html#ab1002450d0de551738c40dc4e1b002ec":[3,0,2,8,6],
 "gphoto2-abilities-list_8c.html#abda07b4f6b0000a5d5f359e6920492e5":[3,0,2,8,5],
+"gphoto2-abilities-list_8c.html#ad6640d5a6a1533a0ea8ced54ab7e9fe4":[3,0,2,8,11],
 "gphoto2-abilities-list_8c.html#aee30e543062b8f2ca10f5c1eb64c9b8d":[3,0,2,8,2],
 "gphoto2-abilities-list_8h.html":[3,0,1,0],
 "gphoto2-abilities-list_8h.html#a0c449b4f3481ce5a8611b052dbd7f88d":[3,0,1,0,13],
@@ -98,7 +99,7 @@ var NAVTREEINDEX0 =
 "gphoto2-abilities-list_8h.html#a325ac3a22209db658e06c0ec1afc099baf32af8452f78ecb327d06f24c816dcff":[3,0,1,0,3,4],
 "gphoto2-abilities-list_8h.html#a35dba5cce03019017bedb69df7fdd6da":[3,0,1,0,8],
 "gphoto2-abilities-list_8h.html#a43ecbdfad0530f0b0089382aa9667f9e":[3,0,1,0,1],
-"gphoto2-abilities-list_8h.html#a574e22027604cfa38e71dda5b899321f":[3,0,1,0,16],
+"gphoto2-abilities-list_8h.html#a574e22027604cfa38e71dda5b899321f":[3,0,1,0,17],
 "gphoto2-abilities-list_8h.html#a8880b2ceed89e39933df14a5a80f8163":[3,0,1,0,9],
 "gphoto2-abilities-list_8h.html#a91d708ad7663e0bd7eaa8ba67b011d3c":[3,0,1,0,4],
 "gphoto2-abilities-list_8h.html#a91d708ad7663e0bd7eaa8ba67b011d3ca6ca4c7fded098ec6089bcab194cca5d9":[3,0,1,0,4,0],
@@ -116,6 +117,7 @@ var NAVTREEINDEX0 =
 "gphoto2-abilities-list_8h.html#ad0d503f618c623e74b1c888c53d5a209ac5e7a50b3ec83e2ca578c67c713e2224":[3,0,1,0,5,2],
 "gphoto2-abilities-list_8h.html#ad0d503f618c623e74b1c888c53d5a209afe827c4e98a518816d2f4100d496d88b":[3,0,1,0,5,0],
 "gphoto2-abilities-list_8h.html#ad0d503f618c623e74b1c888c53d5a209aff73c3e6063e3b932631ee90b8303441":[3,0,1,0,5,1],
+"gphoto2-abilities-list_8h.html#ad6640d5a6a1533a0ea8ced54ab7e9fe4":[3,0,1,0,16],
 "gphoto2-abilities-list_8h.html#adb4109f5f068c42b37b1a6506b60de2f":[3,0,1,0,2],
 "gphoto2-abilities-list_8h.html#adb4109f5f068c42b37b1a6506b60de2fa464a1de0a815804300c84cd2b22733fb":[3,0,1,0,2,0],
 "gphoto2-abilities-list_8h.html#adb4109f5f068c42b37b1a6506b60de2fa66f652e8f43eeb5b4c61e885caa43a65":[3,0,1,0,2,1],
@@ -247,7 +249,5 @@ var NAVTREEINDEX0 =
 "gphoto2-context_8h.html#ae3ccc9d5a652ca165b4a0d22cf6e493fafadd72ed8d05a4692bac36e6f6170a59":[3,0,1,2,2,1],
 "gphoto2-context_8h.html#afefd086439808e0ea31fe982cf2bf742":[3,0,1,2,4],
 "gphoto2-context_8h_source.html":[3,0,1,2],
-"gphoto2-endian_8h_source.html":[3,0,2,11],
-"gphoto2-file_8c.html":[3,0,2,12],
-"gphoto2-file_8c.html#a0376d5d1c7af0edde33cdbe7f3d2eb1e":[3,0,2,12,13]
+"gphoto2-endian_8h_source.html":[3,0,2,11]
 };
